@@ -7,10 +7,6 @@ mod recursive;
 use anyhow::Result;
 use crossbeam_channel::unbounded;
 use notify::{
-    event::{
-        DataChange,
-        ModifyKind,
-    },
     RecommendedWatcher,
     Watcher,
 };
@@ -28,7 +24,7 @@ use std::sync::{
 /// use something like Compare and swap.
 ///
 /// Assume you have a config struct that is called Config
-/// ```no_run
+/// ```ignore
 /// #[derive(serde::Deserialize)]
 /// struct Config {
 ///    key: String,
@@ -77,6 +73,7 @@ where
         }) {
             Ok(event) => match event {
                 Ok(e) => {
+                    tracing::debug!("Actual EVENT: {:#?}", e);
                     // Modify: DataChange::Any gets triggered everytime you open
                     // the config file and perform empty save. It was kind of
                     // annoying so I had to use AccessKind:Close so that I can
@@ -86,16 +83,12 @@ where
                     // If it causes any undefined behaviours, consider changing
                     // back this to Accesskind again.
                     // Full code should be something like this:
-                    // ```rust
+                    // ```ignore
                     // if e.kind == notify::EventKind::Access(AccessKind::Close(
                     //     AccessMode::Write,
                     // )) {...}
                     // ```
-                    if e.kind ==
-                        notify::EventKind::Modify(ModifyKind::Data(
-                            DataChange::Any,
-                        ))
-                    {
+                    if e.kind == notify::EventKind::Any {
                         match f() {
                             Ok(new_config) => {
                                 tracing::debug!(
